@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
+#
+import sys  #
 
 import botocore
 import click
-import enquiries
 import json
 import requests
 
@@ -26,32 +27,54 @@ NEW_RELIC_ENV_VARS = (
 )
 
 
-def index(region, runtime):
+def index(region, runtime, architecture):
     req = requests.get(
-        "https://%s.layers.newrelic-external.com/get-layers?CompatibleRuntime=%s"
-        % (region, runtime)
+        "https://%s.layers.newrelic-external.com/get-layers"
+        "?CompatibleRuntime=%s" % (region, runtime)
     )
     layers_response = req.json()
-    return layers_response.get("Layers", [])
+    return [
+        layer
+        for layer in layers_response.get("Layers", [])
+        if "CompatibleArchitectures" not in layer
+        and architecture == "x86_64"
+        or architecture in layer["CompatibleArchitectures"]
+    ]
 
 
-def layer_selection(available_layers, runtime):
-    selected_layer = []
-    if len(available_layers) > 1:
-        layerOptions = []
-        for layer in available_layers:
-            layerOptions.append(layer["LatestMatchingVersion"]["LayerVersionArn"])
+def layer_selection(available_layers, runtime, architecture):
+    if len(available_layers) == 1:
+        return available_layers[0]["LatestMatchingVersion"]["LayerVersionArn"]
 
-        response = enquiries.choose(
-            "Discovered layers for runtime {0}".format(runtime), layerOptions
+    layer_options = [
+        layer["LatestMatchingVersion"]["LayerVersionArn"] for layer in available_layers
+    ]
+
+    if sys.stdout.isatty():
+        output = "\n".join(
+            [
+                "Discovered multiple layers for runtime %s (%s):"
+                % (runtime, architecture),
+                "",
+            ]
+            + ["%d: %s" % (i, layer) for i, layer in enumerate(layer_options)]
+            + ["", "Select a layer"]
         )
-        success("Layer {0} selected".format(response))
-        selected_layer.append(response)
+
+        while True:
+            value = click.prompt(output, default=0, type=int)
+            try:
+                selected_layer = layer_options[value]
+                success("Layer %s selected" % selected_layer)
+                return selected_layer
+            except IndexError:
+                failure("Invalid layer selection")
     else:
-        selected_layer.append(
-            available_layers[0]["LatestMatchingVersion"]["LayerVersionArn"]
+        raise click.UsageError(
+            "Discovered multiple layers for runtime %s (%s):\n%s\n"
+            "Pass --layer-arn to specify a layer ARN"
+            % (runtime, architecture, "\n".join(layer_options))
         )
-    return selected_layer
 
 
 def _add_new_relic(input, config, nr_license_key):
@@ -67,6 +90,9 @@ def _add_new_relic(input, config, nr_license_key):
         )
         return True
 
+    architectures = config["Configuration"].get("Architectures", ["x86_64"])
+    architecture = architectures[0]
+
     handler = config["Configuration"]["Handler"]
     runtime_handler = utils.RUNTIME_CONFIG.get(runtime, {}).get("Handler")
 
@@ -100,16 +126,16 @@ def _add_new_relic(input, config, nr_license_key):
         new_relic_layer = [input.layer_arn]
     else:
         # discover compatible layers...
-        available_layers = index(aws_region, runtime)
+        available_layers = index(aws_region, runtime, architecture)
 
         if not available_layers:
             failure(
-                "No Lambda layers published for '%s' runtime: %s"
-                % (config["Configuration"]["FunctionArn"], runtime)
+                "No Lambda layers published for %s (%s) runtime: %s"
+                % (config["Configuration"]["FunctionArn"], runtime, architecture)
             )
             return False
 
-        new_relic_layer = layer_selection(available_layers, runtime)
+        new_relic_layer = layer_selection(available_layers, runtime, architecture)
 
     update_kwargs = {
         "FunctionName": config["Configuration"]["FunctionArn"],
@@ -118,7 +144,7 @@ def _add_new_relic(input, config, nr_license_key):
             .get("Environment", {})
             .get("Variables", {})
         },
-        "Layers": new_relic_layer + existing_layers,
+        "Layers": [new_relic_layer] + existing_layers,
     }
 
     # We don't want to modify the handler if the NewRelicLambdaExtension layer
